@@ -20,7 +20,7 @@ Client implementation for using the ZAP pentesting proxy remotely.
 """
 
 __docformat__ = 'restructuredtext'
-__version__ = '0.0.19'
+__version__ = '0.0.21'
 
 import requests
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
@@ -38,6 +38,7 @@ from .autoupdate import autoupdate
 from .brk import brk
 from .context import context
 from .core import core
+from .exim import exim
 from .exportreport import exportreport
 from .forcedUser import forcedUser
 from .graphql import graphql
@@ -45,6 +46,7 @@ from .httpSessions import httpSessions
 from .importLogFiles import importLogFiles
 from .importurls import importurls
 from .localProxies import localProxies
+from .network import network
 from .openapi import openapi
 from .params import params
 from .pnh import pnh
@@ -104,6 +106,7 @@ class ZAPv2(object):
         self.brk = brk(self)
         self.context = context(self)
         self.core = core(self)
+        self.exim = exim(self)
         self.exportreport = exportreport(self)
         self.forcedUser = forcedUser(self)
         self.graphql = graphql(self)
@@ -111,6 +114,7 @@ class ZAPv2(object):
         self.importLogFiles = importLogFiles(self)
         self.importurls = importurls(self)
         self.localProxies = localProxies(self)
+        self.network = network(self)
         self.openapi = openapi(self)
         self.params = params(self)
         self.pnh = pnh(self)
